@@ -7,6 +7,7 @@ use version; our $VERSION = qv('0.0.1');
 use base 'Google::Adwords::Data';
 
 my @fields = qw/
+    _excludedRegions
     _regions
     /;
 
@@ -63,6 +64,35 @@ sub regions
     return $self->get('_regions');
 } # end sub regions
 
+# excludedRegions should always return an array ref
+sub excludedRegions
+{
+    my $self = shift;
+
+    # if its a put
+    if (@_)
+    {
+        my $put_ref = [];
+
+        for (@_)
+        {
+            if ( ref $_ ne 'ARRAY' )
+            {
+                push @{$put_ref}, $_;
+            }
+            else
+            {
+                push @{$put_ref}, @{$_};
+            }
+        }
+
+        $self->set( '_excludedRegions', $put_ref );
+        return $self;
+    } # end if (@_)
+
+    return $self->get('_excludedRegions');
+} # end sub excludedRegions
+
 1;
 
 =pod
